@@ -113,3 +113,19 @@ test('bits and binary option', t => {
 	t.is(prettyBytes(1025, {bits: true, binary: true}), '1 kibit');
 	t.is(prettyBytes(1e6, {bits: true, binary: true}), '977 kibit');
 });
+
+test('fractional digits options', t => {
+	t.is(prettyBytes(1900, {maximumFractionDigits: 1}), '1.9 kB');
+	t.is(prettyBytes(1900, {minimumFractionDigits: 3}), '1.900 kB');
+	t.is(prettyBytes(1911, {maximumFractionDigits: 1}), '1.9 kB');
+	t.is(prettyBytes(1111, {maximumFractionDigits: 2}), '1.11 kB');
+	t.is(prettyBytes(1019, {maximumFractionDigits: 3}), '1.019 kB');
+	t.is(prettyBytes(1001, {maximumFractionDigits: 3}), '1.001 kB');
+	t.is(prettyBytes(1000, {minimumFractionDigits: 1, maximumFractionDigits: 3}), '1.0 kB');
+	t.is(prettyBytes(3942, {minimumFractionDigits: 1, maximumFractionDigits: 2}), '3.94 kB');
+	t.is(prettyBytes(4001, {maximumFractionDigits: 3, binary: true}), '3.907 kiB');
+	t.is(prettyBytes(18717, {maximumFractionDigits: 2, binary: true}), '18.28 kiB');
+	t.is(prettyBytes(18717, {maximumFractionDigits: 4, binary: true}), '18.2783 kiB');
+	t.is(prettyBytes(32768, {minimumFractionDigits: 2, maximumFractionDigits: 3, binary: true}), '32.00 kiB');
+	t.is(prettyBytes(65536, {minimumFractionDigits: 1, maximumFractionDigits: 3, binary: true}), '64.0 kiB');
+});
